==> webkit2gtk_2.42.2.orig.tar.xz: webkitgtk-2.42.2/Source/WebKit/WebProcess/MediaCache/WebMediaKeyStorageManager.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

#include "WebProcessSupplement.h"
#include <wtf/Noncopyable.h>
#include <wtf/WallTime.h>
#include <wtf/text/WTFString.h>

namespace WebCore {
class SecurityOriginData;
}

namespace WebKit {

class WebProcess;

class WebMediaKeyStorageManager : public WebProcessSupplement {
    WTF_MAKE_FAST_ALLOCATED;
    WTF_MAKE_NONCOPYABLE(WebMediaKeyStorageManager);
public:
    explicit WebMediaKeyStorageManager(WebProcess&) { }
    virtual ~WebMediaKeyStorageManager() { }

    static const char* supplementName();

    const String& mediaKeyStorageDirectory() const { return m_mediaKeyStorageDirectory; }
    String mediaKeyStorageDirectoryForOrigin(const WebCore::SecurityOriginData&);

    Vector<WebCore::SecurityOriginData> getMediaKeyOrigins();
    void deleteMediaKeyEntriesForOrigin(const WebCore::SecurityOriginData&);
    void deleteMediaKeyEntriesModifiedBetweenDates(WallTime startDate, WallTime endDate);
    void deleteAllMediaKeyEntries();

private:
    void setWebsiteDataStore(const WebProcessDataStoreParameters&) override;

    String m_mediaKeyStorageDirectory;
};

}

==> webkit2gtk_2.44.2.orig.tar.xz: webkitgtk-2.44.2/Source/WebKit/WebProcess/MediaCache/WebMediaKeyStorageManager.h <==
/*
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#pragma once

#include "WebProcessSupplement.h"
#include <wtf/Noncopyable.h>
#include <wtf/WallTime.h>
#include <wtf/text/WTFString.h>

namespace WebCore {
class SecurityOriginData;
}

namespace WebKit {

class WebProcess;

class WebMediaKeyStorageManager : public WebProcessSupplement {
    WTF_MAKE_FAST_ALLOCATED;
    WTF_MAKE_NONCOPYABLE(WebMediaKeyStorageManager);
public:
    explicit WebMediaKeyStorageManager(WebProcess&) { }
    virtual ~WebMediaKeyStorageManager() { }

    static ASCIILiteral supplementName();

    const String& mediaKeyStorageDirectory() const { return m_mediaKeyStorageDirectory; }
    String mediaKeyStorageDirectoryForOrigin(const WebCore::SecurityOriginData&);

    Vector<WebCore::SecurityOriginData> getMediaKeyOrigins();
    void deleteMediaKeyEntriesForOrigin(const WebCore::SecurityOriginData&);
    void deleteMediaKeyEntriesModifiedBetweenDates(WallTime startDate, WallTime endDate);
    void deleteAllMediaKeyEntries();

private:
    void setWebsiteDataStore(const WebProcessDataStoreParameters&) override;

    String m_mediaKeyStorageDirectory;
};

}
